@@ -55,11 +55,16 @@ public class Main
       }
     catch (ClassNotFoundException e)
       {
-        File jar = new File ("/usr/share/java/libgcj-tools-4.1.1.jar");
+	String version = System.getProperty ("java.vm.version");
+	int space = version.indexOf (' ');
+	if (space != -1)
+	  version = version.substring (0, space);
+	
+        File jar = new File ("/usr/share/java/libgcj-tools-" + version + ".jar");
         if (!jar.exists () || !jar.canRead ())
           {
             System.err.println ("java-gcj-compat: tools.jar: failed to read "
-                                + "/usr/share/java/libgcj-tools-4.1.1.jar");
+                                + jar);
           }
 
         ClassLoader loader = null;
@@ -70,7 +75,7 @@ public class Main
         catch (MalformedURLException f)
           {
             System.err.println ("java-gcj-compat: tools.jar: malformed URL for "
-                                + "/usr/share/java/libgcj-tools-4.1.1.jar");
+                                + jar);
             f.printStackTrace();
           }
 
